@@ -45,11 +45,11 @@ class Domoticz(IPlugin):
 			log.msg("ids  :  %s" % (rs['ids']))
 			if rs['ids'] == idex :
 #				log.msg("index trouvé :  ***")
-				bodies == rs['boy']
+				bodies = rs['boy']
 				log.msg("BODIES  :  %s" % (bodies))
 				log.msg("on off  :  %s" % (on_off))
-				log.msg("number  :  %s" % (rs['idx']))	
-				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (rs['idx'],on_off))
+				log.msg("number  :  %s" % (int(rs['idx'])))	
+				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%02d&switchcmd=%s&level=0' % (int(rs['idx']),on_off))
 				log.msg("resp  :  %s" % (resp))
 		return {"plugin": "Domoticz",
 			"method": "switchlight",
